Learn R Programming

EnTraineR (version 1.0.0)

deforestation: River deforestation: air and water temperatures before/after

Description

Monitoring data of water and air temperatures before and after riparian deforestation. Useful to illustrate linear regression with an interaction (Temp_air * Deforestation).

Usage

data(deforestation)

Arguments

Format

A data frame with 56 rows and 3 variables:

Temp_water

numeric; water temperature (deg C).

Temp_air

numeric; air temperature (deg C).

Deforestation

factor with 2 levels: "BEFORE", "AFTER". 28 periods each.

Details

Brief summary (indicative): Temp_water min ~ 0.55, median ~ 9.28, max ~ 18.89; Temp_air min ~ -3.04, median ~ 6.53, max ~ 15.75.

Examples

Run this code
data(deforestation)
str(deforestation)
table(deforestation$Deforestation)

if (FALSE) { # requireNamespace("FactoMineR", quietly = TRUE)
# Linear model with interaction (FactoMineR):
fit <- FactoMineR::LinearModel(
  Temp_water ~ Temp_air * Deforestation,
  data = deforestation,
  selection = "none"
)
print(fit)
}

Run the code above in your browser using DataLab