Learn R Programming

EnTraineR (version 1.0.0)

trainer_core_actually_shown: Determine which requested items were actually shown after filtering

Description

Determine which requested items were actually shown after filtering

Usage

trainer_core_actually_shown(req_main, req_inter, ttest_filtered)

Value

Character vector of actually shown specifiers.

Arguments

req_main

Character vector of requested main factors.

req_inter

Character vector of requested interactions ("A:B").

ttest_filtered

Filtered T-test lines.

Examples

Run this code
trainer_core_actually_shown("A", "A:B", c("A - a", "A - a : B - b"))

Run the code above in your browser using DataLab